==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoaway/translations/autoaway_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>État</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Autoaway</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Vérifier l&apos;inactivité tous les</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Activer Autoaway</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Mettre en veille après</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Activer l&apos;invisibilité automatique</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Mettre en invisible après</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Activer la déconnexion automatique</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Déconnexion après</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nouvelle description</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Analyser AutoStatus</translation>
    </message>
    <message>
        <source>Enable auto extended away</source>
        <translation>Activer la veille prolongée automatique</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Mettre en veille prolongée après</translation>
    </message>
    <message>
        <source>Auto refresh status</source>
        <translation>État du rafraîchissement automatique</translation>
    </message>
    <message numerus="yes">
        <source>[every] %n second(s)</source>
        <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>[after] %n second(s)</source>
        <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Ne pas modifier</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Ajouter devant</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Ajouter derrière</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Ne pas rafraîchir</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/autoaway/translations/autoaway_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>État</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Vérifier l&apos;inactivité tous les</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Mettre en veille après</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Mettre en invisible après</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nouvelle description</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Mettre en veille prolongée après</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Ne pas modifier</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minute(s)</numerusform><numerusform>%n minute(s)</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prepend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Ne pas rafraîchir</translation>
    </message>
</context>
</TS>
